@@ -6,6 +6,7 @@ import {
 import { parseQuestionOptions } from '@boyuai/jupyter-helper/lib/quiz';
 import { getQuizQuestionByUUID, parseQuizQuestions } from './services';
 import { ICell, IJupyter } from './types';
+import '../css/extension.css';
 
 const Jupyter: IJupyter = (window as any)['Jupyter'];
 export const workRegx = /work\/lessons-(\d+)-(\w+)\.ipynb/;
@@ -134,6 +135,20 @@ const insertMarkdownCellBelow = function (md: string) {
   Jupyter.notebook.focus_cell();
 };
 
+const insertCodeInCurrentMarkdownCell = function (md: string) {
+  const currentIdx = Jupyter.notebook.get_selected_index();
+  if (!currentIdx) {
+    alert('请选中一个 Markdown Cell');
+    return;
+  };
+  const current = Jupyter.notebook.get_cell(currentIdx!);
+  if (current.cell_type !== 'markdown') {
+    alert('请选中一个 Markdown Cell');
+    return;
+  }
+  current.set_text(current.get_text() + '\n' + md);
+}
+
 const addStepDescCells = function () {
   insertMarkdownCellBelow('### 步骤标题');
 
@@ -372,7 +387,8 @@ Player(vid='--替换你的视频id，上传地址 https://www.boyuai.com/elites/
 };
 
 const addDetailStep = function () {
-  insertMarkdownCellBelow(`<details>
+  insertCodeInCurrentMarkdownCell(`
+<details>
 
 <summary>标题</summary>
 
@@ -383,38 +399,36 @@ const addDetailStep = function () {
 };
 
 const addImagePlayerStep = function () {
-  insertMarkdownCellBelow(`<!-- ------请勿修改此处内容------ -->
-
-<!--图片播放器 Begin -->
-
-<div class="image-wrapper">
+  insertCodeInCurrentMarkdownCell(`
+<!-- ---------------------------------------- -->
+<!-- /////////// 图片播放器 Begin /////////// -->
+<!-- ---------------------------------------- -->
+<div class="image-player">
 <div class="image-viewer">
 
-<!-- ------请勿修改此处内容------ -->
-  `);
-  insertMarkdownCellBelow(`<!-- 添加图片资源 -->
+
+<!-------------- 在此处添加图片资源 ------------------->
 <img src="【在此处粘贴替换图片地址】" />
 <img src="【在此处粘贴替换图片地址】" />
 <img src="【在此处粘贴替换图片地址】" />
-<!-- 添加图片资源 -->
-  `);
-  insertMarkdownCellBelow(`<!-- ------请勿修改此处内容------ -->
+<!-------------- 在此处添加图片资源 ------------------->
+
 
 </div>
 <div class="button-wrapper">
 <button class="last"></button>
 <div>
-<span id="current">1</span>
+<span class="current">0</span>
 <span>/</span>
-<span id="total">3</span>
+<span class="total">0</span>
 </div>
 <button class="next"></button>
 </div>
-
-<!--图片播放器 End -->
-
-<!-- ------请勿修改此处内容------ -->
-  `);
+</div>
+<!-- ---------------------------------------- -->
+<!-- /////////// 图片播放器 End //////////// -->
+<!-- ---------------------------------------- -->
+`);
 };
 
 const addFileCell = function () {
